using Confluent.Kafka;

internal class AlphabetConsumer 
{
    ConsumerConfig _consumerConfig;
    public AlphabetConsumer(string connection, string groupId)
    {
        _consumerConfig = new ConsumerConfig
        {
            BootstrapServers = connection,
            GroupId = groupId,
            AutoOffsetReset = AutoOffsetReset.Earliest,
            EnableAutoCommit = true, 
            EnableAutoOffsetStore = true
        };
        Console.WriteLine($"GroupId: {_consumerConfig.GroupId}");
    }

    internal void ReceiveMessagesBatch(string topic, int batchSize, TimeSpan timeout, TimeoutBehavior timeoutBehavior, CancellationToken cancellationToken)
    {
        using IConsumer<string, string> consumer = new ConsumerBuilder<string, string>(_consumerConfig).
        Build();
        consumer.Subscribe(topic);
        
        while (true)
        {
            Console.WriteLine($"Looking for messages on topic: {topic}");
            var consumeResults = consumer.ConsumeBatch(batchSize, timeout, timeoutBehavior, cancellationToken);

            if (!consumeResults.Any())
            {
                Console.WriteLine("No messages received.");
                continue;
            }
            foreach (var consumeResult in consumeResults)
            {
                Console.WriteLine($"Received: '{consumeResult.Message.Value}'. Topic '{consumeResult.Topic}'. Offset: {consumeResult.Offset}.");
            }
        }
    }
}