using System.Diagnostics;
using Confluent.Kafka;

public enum TimeoutBehavior 
{
    StartAfterFirstMessageReceived = 1,
    StartImmediately = 2
}

internal static class ConsumerExtensions
{   
    static Stopwatch stopwatch = new Stopwatch();
    internal static IEnumerable<ConsumeResult<TKey, TValue>> ConsumeBatch<TKey, TValue>(this IConsumer<TKey, TValue> consumer, int maxBatchSize, TimeSpan consumeTimeout, TimeoutBehavior timeoutBehavior, CancellationToken cancellationToken)
    {
        var consumeResults = new List<ConsumeResult<TKey, TValue>>(maxBatchSize);

        if(timeoutBehavior == TimeoutBehavior.StartAfterFirstMessageReceived)
        {
            var result = consumer.Consume(cancellationToken); // this waits for the first message
            consumeResults.Add(result);
        }

        stopwatch.Start();

        while (consumeResults.Count < maxBatchSize && stopwatch.Elapsed < consumeTimeout)
        {
            var result = consumer.Consume(consumeTimeout - stopwatch.Elapsed); // this can timeout
            if (result != null)
            {
                consumeResults.Add(result);
            }
        }
        stopwatch.Reset();
        return consumeResults;
    }
}